module.exports = defineTest({
	description: 'handles variable declarations in catch scopes'
});
